@@ -31,6 +31,7 @@ import operator
 from decimal import Decimal
 import time
 
+from stoqdrivers.printers.base import BaseDriverConstants
 from stoqdrivers.printers.daruma.FS345 import FS345, CMD_GET_TAX_CODES
 from stoqdrivers.enum import UnitType, TaxType
 from stoqdrivers.exceptions import DriverError
@@ -50,10 +51,20 @@ FF  = 255
 
 CMD_ADD_ITEM = 201
 
+class FS2100Constants(BaseDriverConstants):
+    _constants = {
+        UnitType.WEIGHT:      'Kg',
+        UnitType.METERS:      'm ',
+        UnitType.LITERS:      'Lt',
+        UnitType.EMPTY:       'UN',
+        }
+
+
 class FS2100(FS345):
     model_name = "Daruma FS 2100"
 
     def __init__(self, port, consts=None):
+        consts = consts or FS2100Constants
         FS345.__init__(self, port, consts)
 
     def setup(self):
@@ -168,11 +179,21 @@ class FS2100(FS345):
         data = chr(FS) + prefix + data
 
         checksum = reduce(operator.xor, [ord(d) for d in data], 0)
-        self.write(data + chr(checksum))
 
-        retval = self.readline()
+        for t in range(10):
+            self.write(data + chr(checksum))
+            retval = self.readline()
+
+            # See send_command for more details
+            if retval == ':E99' or retval == ':E35':
+                log.debug('FS2100 >>> Error 99. Sleeping for 0.1')
+                time.sleep(0.1)
+            else:
+                break
+
         # After the CR, there is still one byte for the checksum
         retval_checksum = self.read(1)
+        retval_checksum # pyflakes
 
         if not ignore_error:
             self._check_response(retval, data)
