@@ -268,6 +268,9 @@ class Simple(object):
     def setup(self):
         pass
 
+    def has_open_coupon(self):
+        return self.is_coupon_opened
+
     def coupon_identify_customer(self, customer, address, document):
         self._check()
         if document not in ['160.618.061-40',
